import request from '@/utils/request'

// 导航列表
export function navigationList(data) {
	return request({
		url: '/admin/v1/service/innovate/kind',
		method: 'post',
		data,
	})
}
// 导航列表-添加
export function navigationAdd(data) {
	return request({
		url: '/admin/v1/service/innovate/kind/add',
		method: 'post',
		data,
	})
}
// 导航列表-修改
export function navigationEdit(data) {
	return request({
		url: '/admin/v1/service/innovate/kind/edit',
		method: 'post',
		data,
	})
}
// 导航列表-删除
export function navigationDelete(data) {
	return request({
		url: '/admin/v1/service/innovate/kind/delete',
		method: 'post',
		data,
	})
}
// 导航-下拉
export function navigationSelect() {
	return request({
		url: '/admin/v1/service/innovate/kind/select',
	})
}

// 服务列表
export function serviceList(data) {
	return request({
		url: '/admin/v1/service/innovate',
		method: 'post',
		data,
	})
}
// 服务列表-添加
export function serviceAdd(data) {
	return request({
		url: '/admin/v1/service/innovate/add',
		method: 'post',
		data,
	})
}
// 服务列表-详情
export function serviceDetail(data) {
	return request({
		url: '/admin/v1/service/innovate/detail',
		method: 'post',
		data,
	})
}
// 服务列表-修改
export function serviceEdit(data) {
	return request({
		url: '/admin/v1/service/innovate/edit',
		method: 'post',
		data,
	})
}
// 服务列表-删除
export function serviceDelete(data) {
	return request({
		url: '/admin/v1/service/innovate/delete',
		method: 'post',
		data,
	})
}
