<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      v-show="showSearch"
      :inline="true"
      @submit.native.prevent
    >
      <el-form-item label="导航名称:" prop="kind_id">
        <el-select
          v-model="queryParams.kind_id"
          placeholder="请选择"
          size="small"
          style="width: 240px"
          clearable
        >
          <el-option
            v-for="item in kindOptions"
            :key="item.id"
            :label="item.title"
            :value="item.id"
          >
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          >新增</el-button
        >
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="dataList">
      <el-table-column label="数据编号" prop="id" align="center" />
      <el-table-column label="服务标题" prop="title" width="120" />
      <el-table-column label="导航名称" prop="kind_title" align="center" />
      <el-table-column label="所属站点" prop="area" align="center" />
      <el-table-column label="创建时间" prop="created_at" align="center">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.created_at) }}</span>
        </template>
      </el-table-column>
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            >编辑</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>
    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.page_num"
      :limit.sync="queryParams.page_size"
      @pagination="getList"
    />
    <!-- 添加或修改对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="40%">
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-form-item label="所属站点" prop="tenant_id">
          <SiteOptions v-model="form" />
        </el-form-item>
        <el-form-item label="归属导航:" prop="kind_id">
          <el-select v-model="form.kind_id" placeholder="请选择">
            <el-option
              v-for="item in kindOptions"
              :key="item.id"
              :label="item.title"
              :value="item.id"
            >
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="服务标题:" prop="title">
          <el-input v-model="form.title" placeholder="请输入服务标题" />
        </el-form-item>
        <el-form-item label="服务简述:" prop="description">
          <el-input
            v-model="form.description"
            placeholder="请输入服务简述"
            maxlength="20"
          />
        </el-form-item>
        <el-form-item label="服务描述:" prop="content">
          <Editor v-model="form.content" :minHeight="150" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import {
  serviceList,
  serviceAdd,
  serviceDetail,
  serviceEdit,
  serviceDelete,
  navigationSelect,
} from "@/api/website/innovate";
export default {
  data() {
    return {
      is_super: this.$store.getters.is_super,
      loading: true,
      showSearch: true,
      kindOptions: [],
      queryParams: {
        kind_id: undefined,
        page_num: 1,
        page_size: 10,
      },
      total: 0,
      dataList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 表单参数
      form: {},
      rules: {
        title: [
          { required: true, message: "数据名称不能为空", trigger: "blur" },
        ],
        description: [
          { required: true, message: "服务简述不能为空", trigger: "blur" },
        ],
        content: [
          { required: true, message: "服务描述不能为空", trigger: "blur" },
        ],
        tenant_id: [
          {
            required: true,
            message: "所属站点不能为空",
            trigger: ["blur", "change"],
          },
        ],
        kind_id: [
          { required: true, message: "导航名称不能为空", trigger: "change" },
        ],
      },
    };
  },
  methods: {
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    handleQuery() {
      this.queryParams.page_num = 1;
      this.getList();
    },
    getList() {
      this.loading = true;
      serviceList(this.queryParams).then((res) => {
        this.dataList = res.data.data;
        this.total = res.data.count;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.memberOpen = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: undefined,
        tenant_id: undefined,
        kind_id: undefined,
        title: undefined,
        description: undefined,
        content: undefined,
        tags: undefined,
      };
      this.resetForm("form");
    },
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "新增";
    },
    handleUpdate(row) {
      this.reset();
      serviceDetail({ id: row.id }).then((res) => {
        this.form = res.data;
        this.open = true;
        this.title = "修改";
      });
    },
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != undefined) {
            serviceEdit(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            serviceAdd(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$modal
        .confirm('是否确认删除名为"' + row.title + '"的数据项？')
        .then(function () {
          return serviceDelete({ id: row.id });
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
  },
  created() {
    this.getList();
    navigationSelect().then((res) => {
      this.kindOptions = res.data;
    });
  },
};
</script>